Weaviate CLI
============
.. image:: https://raw.githubusercontent.com/semi-technologies/weaviate/19de0956c69b66c5552447e84d016f4fe29d12c9/docs/assets/weaviate-logo.png
    :width: 180
    :align: right
    :alt: Weaviate logo

.. image:: https://travis-ci.com/semi-technologies/weaviate-cli.svg?branch=master
    :target: https://travis-ci.com/semi-technologies/weaviate-cli
    :alt: Build Status (Travis CI)

.. image:: https://badge.fury.io/py/weaviate-cli.svg
    :target: https://badge.fury.io/py/weaviate-cli
    :alt: PyPI version


**Command Line Interface (CLI) tool for interacting with a Weaviate instance directly from your Terminal**

Visit the official `SeMi Technology <https://www.semi.technology/>`_ website for more information about the Weaviate and how to use it in production.

Check out our `weaviate-client <https://pypi.org/project/weaviate-client/>`_ library for interacting with a Weaviate instance using python.

Installation
------------

| Install using: ``pip install weaviate-cli``
| Run using: ``weaviate --help``

Articles
--------

Here are some articles on weaviate: 

- `Semantic Search Queries Return More Informed Results <https://hackernoon.com/semantic-search-queries-return-more-informed-results-nr5335nw>`_
- `Getting Started with Weaviate Python Library <https://towardsdatascience.com/getting-started-with-weaviate-python-client-e85d14f19e4f>`_
- `A sub-50ms neural search with DistilBERT and Weaviate <https://towardsdatascience.com/a-sub-50ms-neural-search-with-distilbert-and-weaviate-4857ae390154>`_
- `SeMI Technology Medium blogs <https://medium.com/semi-technologies>`_

Support
-------

- Use our `Slack Channel <https://join.slack.com/t/weaviate/shared_invite/zt-goaoifjr-o8FuVz9b1HLzhlUfyfddhw>`_ for support or any other question.
- Use the ``weaviate`` tag on `Stackoverflow <https://stackoverflow.com/questions/tagged/weaviate>`_  for questions.
- For bugs and/or problems with the package submit a Github `issue <https://github.com/semi-technologies/weaviate-python-client/issues>`_.

Contributing
------------

- Do you want to contribute to `Weaviate`, read `How to Contribute <https://github.com/semi-technologies/weaviate/blob/master/CONTRIBUTE.md>`_.
